---
name: Feature request
about: Suggest an idea for this project
title: "[FEATURE]"
labels: enhancement
assignees: ''

---

## 🚨🚨 Feature Request

- [ ] Related to an existing [Issue](../issues) 
- [ ] A new implementation (Improvement, Extension) 

### Is your feature request related to a problem?

A clear and concise description of what the problem is. Ex. I have an issue when [...]

### If your feature will improve `HUB`

A clear and concise description of how it will help `HUB`. Please prefer references, if possible [...]


### Description of the possible solution

A clear and concise description of what you want to happen. Add any considered drawbacks.

### An alternative solution to the problem can look like

A clear and concise description of any alternative solutions or features you've considered.

**Teachability, Documentation, Adoption, Migration Strategy**
If you can, explain how users will be able to use this and possibly write out a version the docs.
Maybe a screenshot or design?
